/*
 * @(#)ConfigDB.java
 *
 * Copyright (c) 2002 Sunwest Technologies.
 * http://www.SunwestTek.com
 */

package cfgdb;

import com.sunwesttek.util.config.*;
import cfgtest.*;
import java.sql.*;

/**
 * This class shows how to use XMLConfig to serialize
 * configuration parameters and store/retrieve it from
 * database.
 */
public class ConfigDB {
	public static void main(String[] args) {
		try {
			if (args.length != 1) {
				Usage();
			}

			String op = args[0].toLowerCase();
			if (op.equals("w")) {
				storeConfigToDb();
			} else if (op.equals("r")) {
				retrieveConfigFromDb();
			} else {
				Usage();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	// store config to database
	private static void storeConfigToDb() 
	  throws Exception {
		// create an XMLConfig object
		XMLConfig xc = new XMLConfig();
		
		// create a simple config section
		SimpleConfigSection scs = new SimpleConfigSection();
		scs.shortField = (short)12345;
		scs.setStringField("demo string");
		
		// add section to config
		xc.addSection("SCS", scs);

		Class.forName("org.gjt.mm.mysql.Driver");
		String sql = "insert into tblConfig values (?)";

		Connection conn = 
			DriverManager.getConnection("jdbc:mysql://localhost/test");
		PreparedStatement ps =
			conn.prepareStatement(sql);

		// serialize config to an XML string
		ps.setString(1, xc.toXML());

		ps.executeUpdate();

		System.out.println("Wrote config to db:");
		System.out.println(scs);

		ps.close();
		conn.close();
	}

	// retrieve config from database
	private static void retrieveConfigFromDb() 
		throws Exception {
		Class.forName("org.gjt.mm.mysql.Driver");
		String sql = "select * from tblConfig";

		Connection conn = 
			DriverManager.getConnection("jdbc:mysql://localhost/test");
		PreparedStatement ps =
			conn.prepareStatement(sql);

		ResultSet rs = ps.executeQuery();
		String buffer = rs.getString(1);

		// deserialize XML string to XMLConfig object
		XMLConfig xc = XMLConfig.fromXML(buffer, true);

		System.out.println("Read config from db:");
		System.out.println(xc.getSection(0));

		rs.close();
		ps.close();
		conn.close();
	}

	// print usage
	private static void Usage() {
		System.err.println("java cfgdb.ConfigDB <command>");
		System.err.println("  command:");
		System.err.println("    w - write config to database");
		System.err.println("    r - read config from database");

		System.exit(-1);
	}
}
