/*
 * @(#)ConfigTest.java
 *
 * Copyright (c) 2002 Sunwest Technologies.
 * http://www.SunwestTek.com
 */

package cfgtest;

import com.sunwesttek.util.config.*;
import java.io.*;
import java.util.*;

/**
 * This class shows how to use XMLConfig to define
 * configuration parameters, read and write config
 * files.
 */
public class ConfigTest {
	public static void main(String[] args) {
		try {
			if (args.length != 2) {
				Usage();
			}

			String op = args[0].toLowerCase();
			if (op.equals("-w")) {
				writeConfig(args[1]);
			} else if (op.equals("-r")) {
				readConfig(args[1]);
			} else {
				Usage();
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
		
	// write a demo config to the specified file
	private static void writeConfig(String cFile) 
		throws IOException, InvalidConfigParamException,
					 DuplicateConfigSectionException {
		// create an XMLConfig object
		XMLConfig xc = new XMLConfig("ConfigTest");

		// create a config section with simple parameter fields
	  SimpleConfigSection scs = new SimpleConfigSection();
		scs.shortField = (short)12345;
		scs.setStringField("demo string");

		// create a config section with complex parameter fields
		ComplexConfigSection ccs = new ComplexConfigSection();
		for (int i=0; i<ccs.arrayField.length; i++) {
			ccs.arrayField[i] = (short)(i+1);
		}
		ccs.vectorField.add(new Short((short)123));
		ccs.vectorField.add(new String("demo string"));

		// add sections to config
		xc.addSection("SimpleConfigSection", scs);
		xc.addSection("ComplexConfigSection", ccs);

		System.out.print("Write config to '" + cFile + "'...");
		xc.save(new File(cFile));
		System.out.println("done.\n");
	}
		
	// read config from the specified file
	private static void readConfig(String cFile)
		throws IOException, InvalidConfigSyntaxException {
		System.out.print("Read config from '" + cFile + "'...");
		XMLConfig xc = XMLConfig.load(new File(cFile), true);
		System.out.println("done.\n");

		// get and print all the sections
		ConfigSection[] cs = xc.getAllSections();
		for (int i=0; i<cs.length; i++) {
			System.out.println(cs[i]);
		}
	}

	// print usage
	private static void Usage() {
		System.err.println("java cfgtest.ConfigTest <option> <config file>");
		System.err.println("  option:");
		System.err.println("    -r -- read config from a file");
		System.err.println("    -w -- write config into a file");
		System.err.println("  config file:");
		System.err.println("    configuration file name");

		System.exit(-1);
	}
}
