/*
 * @(#)ConfigClient.java
 *
 * Copyright (c) 2002 Sunwest Technologies.
 * http://www.SunwestTek.com
 */

package cfgtrans;

import com.sunwesttek.util.config.*;
import cfgtest.*;
import java.io.*;
import java.net.*;

/**
 * This class shows how to use XMLConfig to serialize and 
 * transfer configuration parameters between network hosts.
 */
public class ConfigClient {
	public static void main(String[] args) {
		try {
			if (args.length != 1) {
				Usage();
			}

			doTrans(args[0]); 
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	// transfer serialized config parameter to server host
	private static void doTrans(String serverName) 
		throws IOException, InvalidConfigParamException, 
					 DuplicateConfigSectionException {
		// create an XMLConfig object
		XMLConfig xc = new XMLConfig();

		// create a simple config section
		SimpleConfigSection scs = new SimpleConfigSection();
		scs.shortField = (short)12345;
		scs.setStringField("demo string");

		// add section to config
		xc.addSection("SCS", scs);

		Socket sock = new Socket(serverName, ConfigServer.PORT);
		BufferedWriter out = new BufferedWriter(
				new OutputStreamWriter(sock.getOutputStream()));

		// send config to server host
		System.out.println("Sent config to '" + serverName + "'...");
		System.out.println(xc.getSection("SCS"));
		xc.save(out);
		out.flush();

		out.close();
		sock.close();
	}

	// print usage
	private static void Usage() {
		System.err.println("java cfgtrans.ConfigClient <server name>");
		System.err.println("  server name:");
		System.err.println("    server's host name");

		System.exit(-1);
	}
}
